/**********************************************************************
Copyright (c) 2006 Travis Reeder and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
2008 Andy Jefferson - added getNumberOfFields(), getFieldNameForColumn()
    ...
**********************************************************************/
package org.datanucleus.sql4o;

import com.db4o.ObjectContainer;
import com.db4o.ObjectSet;
import com.db4o.ext.ExtObjectSet;
import com.db4o.reflect.ReflectField;
import com.db4o.reflect.generic.GenericReflector;

import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

import org.datanucleus.sql4o.metadata.ObjectSetMetaDataImpl;
import org.datanucleus.sql4o.query.SqlQuery;

/**
 * Implementation of results of an SQL query. Utilises basic DB4O ObjectSet but adds on lookups for
 * field names for column positions.
 */
public class ObjectSetWrapper implements ObjectSet
{
    private ObjectSet results;

    private List<String> selectFields;

    private int index;

    private Object lastResult;

    private Object nextResult;

    private ObjectSetMetaData objectSetMetaData;

    private ObjectContainer oc;

    private SqlQuery sqlQuery;

    public ObjectSetWrapper(ObjectContainer oc, SqlQuery q, ObjectSet results)
    {
        this.oc = oc;
        sqlQuery = q;
        setObjectSet(results);
        if (q.getSelect() != null)
        {
            setSelectFields(q.getSelect().getFields());
        }
        objectSetMetaData = new ObjectSetMetaDataImpl(results, this, oc, sqlQuery);
    }

    public ObjectSetMetaData getMetaData()
    {
        /*
         * if (objectSetMetaData == null) { objectSetMetaData = new ObjectSetMetaDataImpl(results, this, oc, sqlQuery); }
         */
        return objectSetMetaData;
    }

    /**
     * Accessor for the number of returned fields. If the user has specified particular fields then returns that number.
     * If the user specified * notation then the total number of fields is returned.
     * @return Number of fields per item
     */
    public int getNumberOfFields()
    {
        if (hasSelectFields())
            return selectFields.size();
        else
            return objectSetMetaData.getColumnCount();
    }

    /**
     * Accessor for the name of a field returned in an index position.
     * @param fieldIndex Position
     * @return The field name returned there
     */
    public String getFieldNameForColumn(int fieldIndex)
    {
    	return objectSetMetaData.getColumnName(fieldIndex);
    }

    /**
     * This will check the select fields if exists, otherwise it will use the fields on the object 
     * TODO could cache the fields for an object here for superfast return
     * @param fieldIndex
     * @return
     */
    public ReflectField getFieldForColumn(int fieldIndex) 
    throws Sql4oException
    {
        return objectSetMetaData.getColumnReflectField(fieldIndex);
    }

    public ReflectField getFieldForColumn(String fieldName) 
    throws Sql4oException
    {
        if (hasSelectFields() && !selectFields.contains(fieldName))
        {
            throw new Sql4oRuntimeException("Field not found: " + fieldName);
        }

        ReflectField field = objectSetMetaData.getColumnReflectField(fieldName);
        if (field == null)
        {
            throw new Sql4oException("Field " + fieldName + " does not exist.");
        }

        return field;
    }

    public boolean hasSelectFields()
    {
        return (selectFields != null && selectFields.size() > 0 && !selectFields.get(0).equals("*"));
    }

    public ExtObjectSet ext()
    {
        return results.ext();
    }

    public boolean hasNext()
    {
        if (nextResult != null)
            return true;
        return results.hasNext();
    }

    public Result next()
    {
        Object next;
        if (nextResult != null)
        {
            next = nextResult;
            nextResult = null;
        }
        else
        {
            next = results.next();
        }
        lastResult = next;
        index++;
        return new ObjectWrapper(this, next);
    }

    public Result get(int index)
    {
        Object ret = results.get(index);
        lastResult = ret;
        // now replace with array structure based on fields chosen
        // return arrayStruct(ret);
        return new ObjectWrapper(this, ret);

    }

    public void reset()
    {
        results.reset();
    }

    public int size()
    {
        return results.size();
    }

    public boolean isEmpty()
    {
        return results.isEmpty();
    }

    public boolean contains(Object o)
    {
        return results.contains(o);
    }

    public Iterator iterator()
    {
        return this; // results.iterator();
    }

    public Object[] toArray()
    {
        return results.toArray();
    }

    @SuppressWarnings("unchecked")
    public Object[] toArray(Object[] a)
    {
        return results.toArray(a);
    }

    @SuppressWarnings("unchecked")
    public boolean add(Object o)
    {
        return results.add(o);
    }

    public boolean remove(Object o)
    {
        return results.remove(o);
    }

    @SuppressWarnings("unchecked")
    public boolean containsAll(Collection c)
    {
        return results.containsAll(c);
    }

    @SuppressWarnings("unchecked")
    public boolean addAll(Collection c)
    {
        return results.addAll(c);
    }

    @SuppressWarnings("unchecked")
    public boolean addAll(int index, Collection c)
    {
        return results.addAll(index, c);
    }

    @SuppressWarnings("unchecked")
    public boolean removeAll(Collection c)
    {
        return results.removeAll(c);
    }

    @SuppressWarnings("unchecked")
    public boolean retainAll(Collection c)
    {
        return results.retainAll(c);
    }

    public void clear()
    {
        results.clear();
    }

    public boolean equals(Object o)
    {
        return results.equals(o);
    }

    public int hashCode()
    {
        return results.hashCode();
    }

    @SuppressWarnings("unchecked")
    public Object set(int index, Object element)
    {
        return results.set(index, element);
    }

    @SuppressWarnings("unchecked")
    public void add(int index, Object element)
    {
        results.add(index, element);
    }

    public Object remove(int index)
    {
        return results.remove(index);
    }

    public int indexOf(Object o)
    {
        return results.indexOf(o);
    }

    public int lastIndexOf(Object o)
    {
        return results.lastIndexOf(o);
    }

    public ListIterator listIterator()
    {
        return results.listIterator();
    }

    public ListIterator listIterator(int index)
    {
        return results.listIterator(index);
    }

    public List subList(int fromIndex, int toIndex)
    {
        return results.subList(fromIndex, toIndex);
    }

    public void remove()
    {
        results.remove();
    }

    public void setObjectSet(ObjectSet objectSet)
    {
        this.results = objectSet;
    }

    public void setSelectFields(List<String> selectFields)
    {
        this.selectFields = selectFields;
    }

    public Object getLastResult()
    {
        return lastResult;
    }

    /**
     * This should only be used in very rare circumstances
     * @param nextResult
     */
    public void setNextResult(Object nextResult)
    {
        this.nextResult = nextResult;
    }

    public List<String> getSelectFields()
    {
        return selectFields;
    }

    public GenericReflector getReflector()
    {
        return oc.ext().reflector();
    }
}