/**********************************************************************
Copyright (c) 2006 Travis Reeder and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
    ...
**********************************************************************/
package org.datanucleus.sql4o.util;

import com.db4o.reflect.ReflectClass;
import com.db4o.reflect.ReflectField;
import com.db4o.reflect.generic.GenericVirtualField;
import com.db4o.ext.StoredClass;
import com.db4o.ext.StoredField;
import com.db4o.ObjectContainer;

import java.util.*;
import java.text.Collator;

/**
 * 
 */
public class ReflectHelper
{

    /**
     * @param container
     * @return list of ReflectClass objects that have been stored in database
     */
    @SuppressWarnings("unchecked")
    public static List getUserStoredClasses(ObjectContainer container)
    {
        String[] ignore = new String[]{
        // todo: decide which should be filtered for sure
                "java.lang.", "java.util.", "java.math.", "com.db4o.", "j4o.lang.AssemblyNameHint",};

        // Get the known classes
        ReflectClass[] knownClasses = container.ext().knownClasses();

        // Filter them
        List filteredList = new ArrayList();
        for (int i = 0; i < knownClasses.length; i++)
        {
            ReflectClass knownClass = knownClasses[i];
            if (knownClass.isArray() || knownClass.isPrimitive())
            {
                continue;
            }
            boolean take = true;
            for (int j = 0; j < ignore.length; j++)
            {
                if (knownClass.getName().startsWith(ignore[j]))
                {
                    take = false;
                    break;
                }
            }
            if (!take)
            {
                continue;
            }
            StoredClass sc = container.ext().storedClass(knownClass.getName());
            if (sc == null)
            {
                continue;
            }
            filteredList.add(knownClass);
        }

        // Sort them
        Collections.sort(filteredList, new Comparator()
        {
            private Collator comparator = Collator.getInstance();

            public int compare(Object arg0, Object arg1)
            {
                ReflectClass class0 = (ReflectClass) arg0;
                ReflectClass class1 = (ReflectClass) arg1;

                return comparator.compare(class0.getName(), class1.getName());
            }
        });

        return filteredList;
    }

    public static ReflectField[] getDeclaredFieldsInHeirarchy(ReflectClass aClass)
    {
        List<ReflectField> ret = getDeclaredFieldsListInHeirarchy(aClass);
        return ret.toArray(new ReflectField[ret.size()]);
    }

    @SuppressWarnings("unchecked")
    private static List<ReflectField> getDeclaredFieldsListInHeirarchy(ReflectClass aClass)
    {
        if (aClass == null)
            return null;
        List ret = getDeclaredFieldsList(aClass);
        ReflectClass parent = aClass.getSuperclass();
        if (parent != null)
        {
            ret.addAll(getDeclaredFieldsListInHeirarchy(parent));
        }
        return ret;
    }

    @SuppressWarnings("unchecked")
    public static List<ReflectField> getDeclaredFieldsList(ReflectClass aClass)
    {
        List<ReflectField> ret = new ArrayList();
        ReflectField[] fields = aClass.getDeclaredFields();
        // need to filter here because some internal fields are coming through (v4oversion and v4ouuid)
        for (int i = 0; i < fields.length; i++)
        {
            ReflectField field = fields[i];
            if (!(field instanceof GenericVirtualField))
            {
                ret.add(field);
            }
        }
        return ret;
    }

    @SuppressWarnings("unchecked")
    public static StoredField[] getDeclaredFieldsInHeirarchy(StoredClass aClass)
    {
        List<ReflectField> ret = getDeclaredFieldsListInHeirarchy(aClass);
        return ret.toArray(new StoredField[ret.size()]);
    }

    @SuppressWarnings("unchecked")
    private static List getDeclaredFieldsListInHeirarchy(StoredClass aClass)
    {
        if (aClass == null)
            return null;
        List ret = getDeclaredFieldsList(aClass);
        StoredClass parent = aClass.getParentStoredClass();
        if (parent != null)
        {
            ret.addAll(getDeclaredFieldsListInHeirarchy(parent));
        }
        return ret;
    }

    @SuppressWarnings("unchecked")
    public static List<StoredField> getDeclaredFieldsList(StoredClass aClass)
    {
        List<StoredField> ret = new ArrayList();
        StoredField[] fields = aClass.getStoredFields();
        // need to filter here because some internal fields are coming through (v4oversion and v4ouuid)
        for (int i = 0; i < fields.length; i++)
        {
            StoredField field = fields[i];
            if (!(field instanceof GenericVirtualField))
            {
                ret.add(field);
            }
        }
        return ret;
    }

    public static ReflectField[] getDeclaredFields(ReflectClass aClass)
    {
        List<ReflectField> ret = getDeclaredFieldsList(aClass);
        return ret.toArray(new ReflectField[ret.size()]);
    }

    public static ReflectField getDeclaredFieldInHeirarchy(ReflectClass reflectClass, String field)
    {
        ReflectField rf = reflectClass.getDeclaredField(field);
        if (rf == null)
        {
            // check up heirarchy
            ReflectClass parent = reflectClass.getSuperclass();
            if (parent != null)
            {
                return getDeclaredFieldInHeirarchy(parent, field);
            }
        }
        return rf;
    }
}